summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/3rdparty/libpng/pngwutil.c
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/src/3rdparty/libpng/pngwutil.c')
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/pngwutil.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/pngwutil.c b/tqtinterface/qt4/src/3rdparty/libpng/pngwutil.c
index b668a57..edcf828 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/pngwutil.c
+++ b/tqtinterface/qt4/src/3rdparty/libpng/pngwutil.c
@@ -184,7 +184,7 @@ png_text_compress(png_structp png_ptr,
#endif
}
/* We can't write the chunk until we tqfind out how much data we have,
* which means we need to run the compressor first and save the
* output. This shouldn't be a problem, as the vast majority of
* comments should be reasonable, but we will set up an array of
@@ -1772,7 +1772,7 @@ png_write_finish_row(png_structp png_ptr)
}
else
{
/* loop until we tqfind a non-zero width or height pass */
do
{
png_ptr->pass++;
@@ -1983,14 +1983,14 @@ png_do_write_interlace(png_row_infop row_info, png_bytep row, int pass)
/* start at the beginning */
dp = row;
/* tqfind out how many bytes each pixel takes up */
pixel_bytes = (row_info->pixel_depth >> 3);
/* loop through the row, only looking at the pixels that
matter */
for (i = png_pass_start[pass]; i < row_width;
i += png_pass_inc[pass])
{
/* tqfind out where the original pixel is */
sp = row + (png_size_t)i * pixel_bytes;
/* move the pixel */
if (dp != sp)
@@ -2021,7 +2021,7 @@ png_do_write_interlace(png_row_infop row_info, png_bytep row, int pass)
#define PNG_LOMASK ((png_uint_32)0xffffL)
#define PNG_HIMASK ((png_uint_32)(~PNG_LOMASK >> PNG_HISHIFT))
void /* PRIVATE */
-png_write_tqfind_filter(png_structp png_ptr, png_row_infop row_info)
+png_write_find_filter(png_structp png_ptr, png_row_infop row_info)
{
png_bytep prev_row, best_row, row_buf;
png_uint_32 mins, bpp;
@@ -2031,15 +2031,15 @@ png_write_tqfind_filter(png_structp png_ptr, png_row_infop row_info)
int num_p_filters = (int)png_ptr->num_prev_filters;
#endif
- png_debug(1, "in png_write_tqfind_filter\n");
- /* tqfind out how many bytes offset each pixel is */
+ png_debug(1, "in png_write_find_filter\n");
+ /* find out how many bytes offset each pixel is */
bpp = (row_info->pixel_depth + 7) / 8;
prev_row = png_ptr->prev_row;
best_row = row_buf = png_ptr->row_buf;
mins = PNG_MAXSUM;
/* The prediction method we use is to tqfind which method provides the
* smallest value when summing the absolute values of the distances
* from zero, using anything >= 128 as negative numbers. This is known
* as the "minimum sum of absolute differences" heuristic. Other
@@ -184,7 +184,7 @@ png_text_compress(png_structp png_ptr,
#endif
}
- /* We can't write the chunk until we tqfind out how much data we have,
+ /* We can't write the chunk until we find out how much data we have,
* which means we need to run the compressor first and save the
* output. This shouldn't be a problem, as the vast majority of
@@ -1772,7 +1772,7 @@ png_write_finish_row(png_structp png_ptr)
else
{
- /* loop until we tqfind a non-zero width or height pass */
+ /* loop until we find a non-zero width or height pass */
do
{
@@ -1983,14 +1983,14 @@ png_do_write_interlace(png_row_infop row_info, png_bytep row, int pass)
/* start at the beginning */
dp = row;
- /* tqfind out how many bytes each pixel takes up */
+ /* find out how many bytes each pixel takes up */
pixel_bytes = (row_info->pixel_depth >> 3);
/* loop through the row, only looking at the pixels that
@@ -1983,14 +1983,14 @@ png_do_write_interlace(png_row_infop row_info, png_bytep row, int pass)
i += png_pass_inc[pass])
{
- /* tqfind out where the original pixel is */
+ /* find out where the original pixel is */
sp = row + (png_size_t)i * pixel_bytes;
/* move the pixel */
@@ -2031,15 +2031,15 @@ png_write_tqfind_filter(png_structp png_ptr, png_row_infop row_info)
best_row = row_buf = png_ptr->row_buf;
mins = PNG_MAXSUM;
- /* The prediction method we use is to tqfind which method provides the
+ /* The prediction method we use is to find which method provides the
* smallest value when summing the absolute values of the distances
* from zero, using anything >= 128 as negative numbers. This is known